import { ActionRowBuilder } from "discord.js";
import { reply, isButtonComponent } from "../../utils/index.js";
import { AudioPlayerStatus, VoiceConnectionStatus, getVoiceConnection, } from "@discordjs/voice";
export async function handlePauseButton(interaction, queue) {
    const connection = getVoiceConnection(interaction.guildId || "");
    if (!connection || connection.state.status !== VoiceConnectionStatus.Ready) {
        await interaction.update({ components: [] });
        return;
    }
    const player = connection.state.subscription?.player;
    if (!player || player.state.status !== AudioPlayerStatus.Playing) {
        await interaction.update({ components: [] });
        return;
    }
    const row = interaction.message.components[0];
    if (!isButtonComponent(row)) {
        await interaction.update({ components: [] });
        return;
    }
    const resume = ActionRowBuilder.from(row);
    const item = resume.components[0];
    if (!item) {
        await interaction.update({ components: [] });
        return;
    }
    item.setCustomId("resume");
    item.setLabel("Resume");
    item.setEmoji("▶️");
    try {
        connection.state.subscription?.player.pause();
        await interaction.update({ components: [resume] });
        await reply(interaction.message, "✨ Paused");
    }
    catch (e) {
        queue.delete(interaction.guildId || "");
        await interaction.reply("An error occurred while trying to pause the music");
        console.error(e);
    }
}
