import { ActionRowBuilder } from "discord.js";
import { reply, isButtonComponent } from "../../utils/index.js";
import { AudioPlayerStatus, VoiceConnectionStatus, getVoiceConnection, } from "@discordjs/voice";
export async function handleResumeButton(interaction, queue) {
    const connection = getVoiceConnection(interaction.guildId || "");
    if (!connection || connection.state.status !== VoiceConnectionStatus.Ready) {
        await interaction.update({ components: [] });
        return;
    }
    const player = connection.state.subscription?.player;
    if (player && player.state.status !== AudioPlayerStatus.Paused) {
        await interaction.update({ components: [] });
        return;
    }
    const row = interaction.message.components[0];
    if (!isButtonComponent(row)) {
        await interaction.update({ components: [] });
        return;
    }
    const pause = ActionRowBuilder.from(row);
    const item = pause.components[0];
    if (!item) {
        await interaction.update({ components: [] });
        return;
    }
    item.setCustomId("pause");
    item.setLabel("Pause");
    item.setEmoji("⏸");
    try {
        connection.state.subscription?.player.unpause();
        await interaction.update({ components: [pause] });
        await reply(interaction.message, "✨ Resumed");
    }
    catch (e) {
        queue.delete(interaction.guildId || "");
        await interaction.reply("An error occurred while trying to resume the music");
        console.error(e);
    }
}
