import { EmbedBuilder } from "discord.js";
import { AudioPlayerStatus, VoiceConnectionStatus, getVoiceConnection, } from "@discordjs/voice";
export async function handleQueue(interaction, queue) {
    const server_queue = queue.get(interaction.guildId);
    const embed = new EmbedBuilder().setTitle("Music Queue").setColor(0x0099ff);
    if (!server_queue || server_queue.queue.length === 0) {
        embed.setDescription("No songs in queue");
        await interaction.reply({ embeds: [embed] });
        return;
    }
    const connection = getVoiceConnection(interaction.guildId);
    if (!connection || connection.state.status !== VoiceConnectionStatus.Ready) {
        embed.setDescription("Not connected to voice channel");
        await interaction.reply({ embeds: [embed] });
        return;
    }
    const queue_list = server_queue.queue.map((song, index) => {
        return `${index + 1}. ${song}`;
    });
    const player = connection.state.subscription?.player;
    if (!player) {
        embed.setDescription("No songs in queue");
        await interaction.reply({ embeds: [embed] });
        return;
    }
    if (player.state.status === AudioPlayerStatus.Playing) {
        const playback = player.state.playbackDuration;
        const resource = player.state.resource;
        const videoDuration = resource.metadata.length;
        const progress = Math.round((playback / 1000 / videoDuration) * 10);
        const progressbar = "▬".repeat(progress) + "🔘" + "▬".repeat(10 - progress);
        const current = new Date(playback).toString().split(" ")[4]?.substring(3);
        const total = new Date(videoDuration * 1000)
            .toString()
            .split(" ")[4]
            ?.substring(3);
        embed.addFields({ name: "Now Playing", value: resource.metadata.title }, { name: "Progress", value: `${progressbar} ${current} / ${total}` });
    }
    embed.setDescription(queue_list.join("\n"));
    await interaction.reply({ embeds: [embed] });
}
